aboutsummaryrefslogtreecommitdiffstats
path: root/include/net.h
diff options
context:
space:
mode:
authorJoerie de Gram <j.de.gram@gmail.com>2011-08-17 15:57:47 +0200
committerJoerie de Gram <j.de.gram@gmail.com>2011-08-17 15:57:47 +0200
commitd3bd80a932e4f76b6cae280c78f118882f3b176d (patch)
treecad99877da53cad9fae5907fd43fe5a79e50ad37 /include/net.h
parenta3c46bd32430db57b97a1498d3da9a2c01df22ad (diff)
downloadexternal_libsamsung-ipc-d3bd80a932e4f76b6cae280c78f118882f3b176d.zip
external_libsamsung-ipc-d3bd80a932e4f76b6cae280c78f118882f3b176d.tar.gz
external_libsamsung-ipc-d3bd80a932e4f76b6cae280c78f118882f3b176d.tar.bz2
Rename library to libsamsung-ipc
Diffstat (limited to 'include/net.h')
-rw-r--r--include/net.h86
1 files changed, 43 insertions, 43 deletions
diff --git a/include/net.h b/include/net.h
index 34114a4..8e650e9 100644
--- a/include/net.h
+++ b/include/net.h
@@ -1,61 +1,61 @@
/**
* This file is part of libmsm-h1.
*
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
*
* libmsm-h1 is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* libmsm-h1 is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with libmsm-h1. If not, see <http://www.gnu.org/licenses/>.
+ * along with libsamsung-ipc. If not, see <http://www.gnu.org/licenses/>.
*
*/
#ifndef __NET_H__
#define __NET_H__
-#define MSM_NET_PREF_PLMN 0x0801
-#define MSM_NET_PLMN_SEL 0x0802
-#define MSM_NET_CURRENT_PLMN 0x0803
-#define MSM_NET_PLMN_LIST 0x0804
-#define MSM_NET_REGIST 0x0805
-#define MSM_NET_SUBSCRIBER_NUM 0x0806
-#define MSM_NET_BAND_SEL 0x0807
-#define MSM_NET_SERVICE_DOMAIN_CONFIG 0x0808
-#define MSM_NET_POWERON_ATTACH 0x0809
-#define MSM_NET_MODE_SEL 0x080A
-#define MSM_NET_ACQ_ORDER 0x080B
-#define MSM_NET_IDENTITY 0x080C
-#define MSM_NET_CURRENT_RRC_STATUS 0x080D
+#define IPC_NET_PREF_PLMN 0x0801
+#define IPC_NET_PLMN_SEL 0x0802
+#define IPC_NET_CURRENT_PLMN 0x0803
+#define IPC_NET_PLMN_LIST 0x0804
+#define IPC_NET_REGIST 0x0805
+#define IPC_NET_SUBSCRIBER_NUM 0x0806
+#define IPC_NET_BAND_SEL 0x0807
+#define IPC_NET_SERVICE_DOMAIN_CONFIG 0x0808
+#define IPC_NET_POWERON_ATTACH 0x0809
+#define IPC_NET_MODE_SEL 0x080A
+#define IPC_NET_ACQ_ORDER 0x080B
+#define IPC_NET_IDENTITY 0x080C
+#define IPC_NET_CURRENT_RRC_STATUS 0x080D
-#define MSM_NET_SERVICE_TYPE_GSM 0x01
-#define MSM_NET_SERVICE_TYPE_GSM2 0x02
-#define MSM_NET_SERVICE_TYPE_GPRS 0x03
-#define MSM_NET_SERVICE_TYPE_EDGE 0x04
-#define MSM_NET_SERVICE_TYPE_UMTS 0x05
+#define IPC_NET_SERVICE_TYPE_GSM 0x01
+#define IPC_NET_SERVICE_TYPE_GSM2 0x02
+#define IPC_NET_SERVICE_TYPE_GPRS 0x03
+#define IPC_NET_SERVICE_TYPE_EDGE 0x04
+#define IPC_NET_SERVICE_TYPE_UMTS 0x05
-#define MSM_NET_SERVICE_LEVEL_NONE 0x01
-#define MSM_NET_SERVICE_LEVEL_HOME 0x02
-#define MSM_NET_SERVICE_LEVEL_SEARCHING 0x03
-#define MSM_NET_SERVICE_LEVEL_EMERGENCY 0x04
-#define MSM_NET_SERVICE_LEVEL_NONE2 0x05
-#define MSM_NET_SERVICE_LEVEL_ROAMING 0x06
+#define IPC_NET_SERVICE_LEVEL_NONE 0x01
+#define IPC_NET_SERVICE_LEVEL_HOME 0x02
+#define IPC_NET_SERVICE_LEVEL_SEARCHING 0x03
+#define IPC_NET_SERVICE_LEVEL_EMERGENCY 0x04
+#define IPC_NET_SERVICE_LEVEL_NONE2 0x05
+#define IPC_NET_SERVICE_LEVEL_ROAMING 0x06
-#define MSM_NET_PLMN_STATUS_AVAILABLE 2
-#define MSM_NET_PLMN_STATUS_CURRENT 3
-#define MSM_NET_PLMN_STATUS_FORBIDDEN 4
+#define IPC_NET_PLMN_STATUS_AVAILABLE 2
+#define IPC_NET_PLMN_STATUS_CURRENT 3
+#define IPC_NET_PLMN_STATUS_FORBIDDEN 4
-#define MSM_NET_PLMN_SEL_MANUAL 0
-#define MSM_NET_PLMN_SEL_AUTO 1
+#define IPC_NET_PLMN_SEL_MANUAL 0
+#define IPC_NET_PLMN_SEL_AUTO 1
-struct msm_net_current_plmn {
+struct ipc_net_current_plmn {
char unk;
unsigned char slevel;
char plmn[6];
@@ -63,35 +63,35 @@ struct msm_net_current_plmn {
unsigned short lac;
} __attribute__((__packed__));
-struct msm_net_regist_set {
+struct ipc_net_regist_set {
unsigned char net;
unsigned char domain;
} __attribute__((__packed__));
-struct msm_net_regist {
+struct ipc_net_regist {
unsigned char act, domain, status, edge;
unsigned short lac;
unsigned int cid;
char rej_cause;
} __attribute__((__packed__));
-struct msm_net_plmn_entry {
+struct ipc_net_plmn_entry {
unsigned char status;
char plmn[6];
unsigned char type;
char unk[2];
} __attribute__((__packed__));
-struct msm_net_plmn_entries {
+struct ipc_net_plmn_entries {
unsigned char num;
- struct msm_net_plmn_entry *data;
+ struct ipc_net_plmn_entry *data;
};
-void msm_net_current_plmn(int request_id);
-void msm_net_plmn_list(int request_id);
-void msm_net_identity(int request_id);
-void msm_net_regist(int request_id, unsigned char type);
+void ipc_net_current_plmn(int request_id);
+void ipc_net_plmn_list(int request_id);
+void ipc_net_identity(int request_id);
+void ipc_net_regist(int request_id, unsigned char type);
#endif
@@ -1,61 +1,61 @@
/**
- * This file is part of libmsm-h1.
+ * This file is part of libsamsung-ipc.
*
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
@@ -1,61 +1,61 @@
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
*
- * libmsm-h1 is free software: you can redistribute it and/or modify
+ * libsamsung-ipc is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -1,61 +1,61 @@
* (at your option) any later version.
*
- * libmsm-h1 is distributed in the hope that it will be useful,
+ * libsamsung-ipc is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the